library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity spi_clk is
	GENERIC (
			clk_set : integer;
			clk_cycles : integer;
			clk_duty_activ : integer;
			clk_duty_inactiv : integer;
			clk_polarity : STD_LOGIC
			);
	
    PORT (	clk : in  STD_LOGIC;
			reset : in  STD_LOGIC;
			enable : in  STD_LOGIC;
			position : in  INTEGER;
			spi_clk_out : out  STD_LOGIC
		   );
end spi_clk;

architecture Behavioral of spi_clk is

signal help_counter : integer;

begin

SPI_clock : process(clk, reset)
begin
	if clk'event and clk = '1' then
		if reset = '1' OR enable = '0' then -- synchronous reset
		spi_clk_out <= NOT clk_polarity;
		help_counter <= 0;
		elsif position >= clk_set AND position < clk_set + clk_cycles * (clk_duty_activ + clk_duty_inactiv) then -- if in allowed frame
			if help_counter <= clk_duty_activ - 1 then -- set output to active value of clk
			spi_clk_out <= clk_polarity;
			help_counter <= help_counter + 1;
			elsif help_counter <= clk_duty_activ + clk_duty_inactiv - 2 then -- set output to inactive value of clk
			spi_clk_out <= NOT clk_polarity;
			help_counter <= help_counter + 1;
			else
			help_counter <= 0;
			spi_clk_out <= NOT clk_polarity;
			end if;
		else
		spi_clk_out <= NOT clk_polarity;
		end if;
	end if;
end process;


end Behavioral;

