library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity spi_send is
	GENERIC (
			send_set : integer;
			send_duty : integer;
			send_polarity : STD_LOGIC;
			send_number_of_bits : integer
			);
	
    PORT (	clk : in  STD_LOGIC;
			reset : in  STD_LOGIC;
			enable : in  STD_LOGIC;
			position : in  INTEGER;
			spi_p_data_in : in  STD_LOGIC_VECTOR(send_number_of_bits-1 downto 0);
			spi_s_data_out : out  STD_LOGIC
		   );
end spi_send;

architecture Behavioral of spi_send is

signal help_counter : integer;
signal pointer : integer range 0 to send_number_of_bits-1 := 0;

begin

SPI_send : process(clk, reset)
begin
	if clk'event and clk = '1' then
		if reset = '1' OR enable = '0' then -- synchronous reset
		help_counter <= 0;
		pointer <= send_number_of_bits-1;
		spi_s_data_out <= NOT send_polarity;
		elsif position >= send_set AND position < send_set + (send_number_of_bits * send_duty) then -- while inside the allowed timeslot
		help_counter <= help_counter + 1;
		spi_s_data_out <= spi_p_data_in(pointer); -- data is shifted out serial
			if help_counter = send_duty - 1 then 
				if pointer = 0 then
				pointer <= send_number_of_bits-1;
				help_counter <= 0;
				spi_s_data_out <= NOT send_polarity;
				else
				pointer <= pointer - 1;
				help_counter <= 0;
				end if;
			end if;
		end if;
	end if;
end process;

end Behavioral;

